@@ -185,6 +185,7 @@ cifreg01 <- function(data,X,exit,status,id=NULL,strata=NULL,offset=NULL,weights=
     data$statusC <- statusC
     cens.strata <- cens.nstrata <- NULL
 
+    if (length(whereC)>0) {
     if (is.null(Gc)) {
         kmt <- TRUE
         if (class(cens.model)[1]=="formula") {
@@ -202,6 +203,14 @@ cifreg01 <- function(data,X,exit,status,id=NULL,strata=NULL,offset=NULL,weights=
         Stime <- Gc
         Pcens.model <- list(time=exit,surv=Gc,strata=0)
         nCstrata <- 1
+	cens.strata <- rep(0,length(exit))
+    }
+    } else { 
+	formC <- NULL
+        Stime <- Gc  <- rep(1,length(exit))
+        Pcens.model <- list(time=exit,surv=Gc,strata=0)
+        nCstrata <- 1
+	cens.strata <- rep(0,length(exit))
     }
 
     Zcall <- cbind(status,cens.strata,Stime) ## to keep track of status and Censoring strata
@@ -262,8 +271,6 @@ cifreg01 <- function(data,X,exit,status,id=NULL,strata=NULL,offset=NULL,weights=
     }# }}}
 
 
-
-
     obj <- function(pp,all=FALSE) {# {{{
 
         if (length(other)>=1)  {
@@ -361,7 +368,7 @@ cifreg01 <- function(data,X,exit,status,id=NULL,strata=NULL,offset=NULL,weights=
             with(out,structure(-ploglik, gradient=-gradient, hessian=-hessian))
     }# }}}
 
-    if (length(jumps)==0) no.opt <- TRUE
+   if (length(jumps)==0) no.opt <- TRUE
 
     opt <- NULL
     if (p>0) {# {{{
@@ -381,6 +388,7 @@ cifreg01 <- function(data,X,exit,status,id=NULL,strata=NULL,offset=NULL,weights=
         val <- obj(0,all=TRUE)
     }# }}}
 
+
 ###    browser()
 ### opt <- lava::NR(beta,obj); beta.s <- opt$par
     beta.s <- val$coef
@@ -411,6 +419,7 @@ cifreg01 <- function(data,X,exit,status,id=NULL,strata=NULL,offset=NULL,weights=
     mid <- max(xx2$id)
     UU <- apply(MGt,2,sumstrata,xx2$id,mid+1)
 
+
     if (length(other)>=1) { ## martingale part for type-2 after T
 
 ### xx2 data all data
@@ -753,7 +762,6 @@ colnames(preds) <- c("pred",paste("se",conf.type[1],sep="-"),"lower","upper")
 return(preds)
 }# }}}
 
-
 ##' @export
 strataC <- survival:::strata
 
@@ -770,7 +778,7 @@ strataC <- survival:::strata
 ##' using a KM for \deqn{G_c(t)} and a working model for cumulative baseline
 ##' related to \deqn{F_1^*(t,s)} and \deqn{s} is strata,
 ##' \deqn{S^*(t,s) = 1 - F_1^*(t,s) - F_2^*(t,s)}, and
-##' \deqn{E(\beta^p,t)} is given.
+##' \deqn{E(\beta^p,t)} is given. Assumes that no strata for baseline of ine-Gay model that is augmented. 
 ##'
 ##' After a couple of iterations we end up with a solution of
 ##' \deqn{
@@ -939,6 +947,7 @@ FG_AugmentCifstrata <- function(formula,data=data,E=NULL,cause=NULL,cens.code=0,
     statusE <- (status==cause)
     if (sum(statusE)==0) stop("No events of type 1 before time \n");
 
+
     ## sorting after time and statusC, but event times unique after order
     Zcall <- cbind(status,strata)
     dd <- .Call("FastCoxPrepStrata",entry,exit,statusC,X,id,
@@ -954,7 +963,7 @@ FG_AugmentCifstrata <- function(formula,data=data,E=NULL,cause=NULL,cens.code=0,
     jumpsD <- which(xxstatus!=cens.code)
     rr <- c(dd$sign*exp(dd$offset))
     ## S0 after strata
-    S0 = c(revcumsumstrata(rr,strata,nstrata))
+    S0 = c(revcumsumstrata(rr,xxstrata,nstrata))
     ## S0 after strataC
     S00C = c(revcumsumstrata(rr,xxstrataC,nstrataC))
 
@@ -1001,7 +1010,7 @@ FG_AugmentCifstrata <- function(formula,data=data,E=NULL,cause=NULL,cens.code=0,
     tailcstrata <- tailstrata(xxstrataC,nstrataC)
     Gcstart <- Gc[tailcstrata]
 
-    dstrata <- mystrata(data.frame(cbind(xxstrataC,xxstrata)))
+    dstrata <- mystrata2index(cbind(xxstrataC,xxstrata))
     ndstrata <- attr(dstrata,"nlevel")
     lastt <- tailstrata(dstrata-1,ndstrata)
 
@@ -1018,12 +1027,11 @@ FG_AugmentCifstrata <- function(formula,data=data,E=NULL,cause=NULL,cens.code=0,
     }
     ERLam1fg0  <- apply(Et,2,fff)
 
-    gt <-  RLam1fg*c(cif2/(Gc*St))
-    gt[gt==Inf] <- 0
-    gt[is.na(gt)] <- 0
-    ERLam1fg  <- ERLam1fg0*c(cif2/(Gc*St))
-    ERLam1fg[ERLam1fg==Inf] <- 0
-    ERLam1fg[is.na(ERLam1fg)] <- 0
+    cif2GS <-  c(cif2/(Gc*St))
+    cif2GS[St<0.00001] <- 0
+    cif2GS[Gc<0.00001] <- 0
+    gt <-  RLam1fg*cif2GS
+    ERLam1fg  <- ERLam1fg0*cif2GS
 
     sss <- headstrata(dstrata-1,ndstrata)
     gtstart <- gt[sss]
@@ -1060,16 +1068,21 @@ FG_AugmentCifstrata <- function(formula,data=data,E=NULL,cause=NULL,cens.code=0,
     if (nstrataC==1) cens.model <- ~+1 else cens.model <- ~strata(strataCC)
     data$strataCC <- cens.strata
 
-    fga <- cifreg(formulans,data=data,cause=cause,
-                  propodds=NULL,augmentation=augment$augment,cens.model=cens.model,...)
+    fga <- tryCatch(cifreg(formulans,data=data,cause=cause,
+                  propodds=NULL,augmentation=augment$augment,cens.model=cens.model,...),error=function(x) NULL) 
 
+    if (!is.null(fga)) {
     ## adjust SE and var based on augmentation term
     fga$var.orig <- fga$var
     fga$augment <- augment$augment
-    fga$iid <- fga$iid + MGiid %*% fga$ihessian
+    fga$iid <- fga$iid.naive + MGiid %*% fga$ihessian
     fga$var <- crossprod(fga$iid)
     fga$se.coef <-  diag(fga$var)^.5
     fga$MGciid <- MGiid
+    } else  {
+    fga$augment <- augment$augment
+    fga$MGciid <- MGiid
+    }
 
     return(fga)
 }# }}})
